@@ -443,7 +443,7 @@ public abstract class AbstractUndoManagerTest {
 	}
 
 	private static String createRandomString(int length) {
-		final StringBuffer buffer= new StringBuffer();
+		final StringBuilder buffer= new StringBuilder();
 
 		for (int i= 0; i < length; i++)
 			buffer.append(getRandomCharacter());
