@@ -1,5 +1,5 @@
 /**
- *  Copyright (c) 2017 Angelo ZERR.
+ *  Copyright (c) 2017, 2021 Angelo ZERR.
  *
  *  This program and the accompanying materials
  *  are made available under the terms of the Eclipse Public License 2.0
@@ -10,12 +10,14 @@
  *
  *  Contributors:
  *  Angelo Zerr <angelo.zerr@gmail.com> - [CodeMining] Provide extension point for CodeMining - Bug 528419
+ *  Christoph Läubrich - Bug 570727 - [codemining] Codeminings computed multiple times
  */
 package org.eclipse.jface.text.codemining;
 
 import org.eclipse.jface.text.IDocument;
 import org.eclipse.jface.text.ITextViewer;
 import org.eclipse.jface.text.reconciler.Reconciler;
+import org.eclipse.jface.text.source.ISourceViewerExtension5;
 
 /**
  * A reconciler which update code minings.
@@ -24,24 +26,32 @@ import org.eclipse.jface.text.reconciler.Reconciler;
  */
 public class CodeMiningReconciler extends Reconciler {
 
-	private CodeMiningStrategy fStrategy;
+	private static final String KEY= CodeMiningReconciler.class.getName();
 
 	public CodeMiningReconciler() {
 		super.setIsIncrementalReconciler(false);
-		fStrategy= new CodeMiningStrategy();
-		this.setReconcilingStrategy(fStrategy, IDocument.DEFAULT_CONTENT_TYPE);
+		this.setReconcilingStrategy(new CodeMiningStrategy(() -> getTextViewer()), IDocument.DEFAULT_CONTENT_TYPE);
 	}
 
 	@Override
 	public void install(ITextViewer textViewer) {
-		super.install(textViewer);
-		fStrategy.install(textViewer);
+		if (mustInstall(textViewer)) {
+			super.install(textViewer);
+			textViewer.getTextWidget().setData(KEY, this);
+		}
 	}
 
 	@Override
 	public void uninstall() {
-		super.uninstall();
-		fStrategy.uninstall();
+		ITextViewer viewer= getTextViewer();
+		if (viewer != null && viewer.getTextWidget().getData(KEY) == this) {
+			super.uninstall();
+			viewer.getTextWidget().setData(KEY, null);
+		}
 	}
 
+
+	private static boolean mustInstall(ITextViewer textViewer) {
+		return textViewer instanceof ISourceViewerExtension5 && textViewer.getTextWidget().getData(KEY) == null;
+	}
 }
