@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -15,6 +15,7 @@
  *     Terry Parker, tparker@google.com - Protect against poorly behaved completion proposers - http://bugs.eclipse.org/429925
  *     Lars Vogel <Lars.Vogel@vogella.com> - Bug 493649
  *     Mickael Istria (Red Hat Inc.) - [251156] Allow multiple contentAssitProviders internally & inheritance
+ *     Christoph Läubrich - Bug 508821 - [Content assist] More flexible API in IContentAssistProcessor to decide whether to auto-activate or not
  *******************************************************************************/
 package org.eclipse.jface.text.contentassist;
 
@@ -99,6 +100,7 @@ import org.eclipse.jface.text.IRewriteTarget;
 import org.eclipse.jface.text.ITextViewer;
 import org.eclipse.jface.text.ITextViewerExtension;
 import org.eclipse.jface.text.TextUtilities;
+import org.eclipse.jface.text.contentassist.ContentAssistant.TriggerType;
 
 
 /**
@@ -376,7 +378,7 @@ class CompletionProposalPopup implements IContentAssistListener {
 				if (fContentAssistant.isAutoActivation() && offset > 0 && event != null) {
 					try {
 						char charBeforeOffset= event.getDocument().getChar(offset - 1);
-						if (fContentAssistant.isAutoActivationTriggerChar(charBeforeOffset)) {
+						if (fContentAssistant.getAutoActivationTriggerType(charBeforeOffset) != TriggerType.NONE) {
 							fContentAssistant.fireSessionBeginEvent(true);
 							showProposals(true);
 						}
@@ -860,8 +862,9 @@ class CompletionProposalPopup implements IContentAssistListener {
 		TableItem item= (TableItem) event.item;
 		int index= fProposalTable.indexOf(item);
 
-		if (0 <= index && index < fFilteredProposals.size()) {
-			ICompletionProposal current= fFilteredProposals.get(index);
+		List<ICompletionProposal> proposals= fFilteredProposals;
+		if (0 <= index && index < proposals.size()) {
+			ICompletionProposal current= proposals.get(index);
 
 			String displayString;
 			StyleRange[] styleRanges= null;
@@ -928,9 +931,11 @@ class CompletionProposalPopup implements IContentAssistListener {
 			return null;
 
 		int i= fProposalTable.getSelectionIndex();
-		if (fFilteredProposals == null || i < 0 || i >= fFilteredProposals.size())
+		List<ICompletionProposal> proposals= fFilteredProposals;
+		if (proposals == null || i < 0 || i >= proposals.size()) {
 			return null;
-		return fFilteredProposals.get(i);
+		}
+		return proposals.get(i);
 	}
 
 	/**
@@ -957,7 +962,6 @@ class CompletionProposalPopup implements IContentAssistListener {
 	 * @since 2.1
 	 */
 	void insertProposal(ICompletionProposal p, char trigger, int stateMask, final int offset) {
-
 		fInserting= true;
 		IRewriteTarget target= null;
 		IEditingSupport helper= new IEditingSupport() {
@@ -975,9 +979,7 @@ class CompletionProposalPopup implements IContentAssistListener {
 		};
 
 		try {
-
 			IDocument document= fContentAssistSubjectControlAdapter.getDocument();
-
 			if (fViewer instanceof ITextViewerExtension) {
 				ITextViewerExtension extension= (ITextViewerExtension) fViewer;
 				target= extension.getRewriteTarget();
@@ -1298,6 +1300,10 @@ class CompletionProposalPopup implements IContentAssistListener {
 
 	@Override
 	public boolean verifyKey(VerifyEvent e) {
+		if (fInserting) {
+			return false;
+		}
+
 		if (!isValid(fProposalShell))
 			return true;
 
@@ -1408,12 +1414,13 @@ class CompletionProposalPopup implements IContentAssistListener {
 		if (oldProposal instanceof ICompletionProposalExtension2 && fViewer != null)
 			((ICompletionProposalExtension2) oldProposal).unselected(fViewer);
 
-		if (fFilteredProposals == null) {
+		List<ICompletionProposal> proposals= fFilteredProposals;
+		if (proposals == null || index >= proposals.size()) {
 			fireSelectionEvent(null, smartToggle);
 			return;
 		}
 
-		ICompletionProposal proposal= fFilteredProposals.get(index);
+		ICompletionProposal proposal= proposals.get(index);
 		if (proposal instanceof ICompletionProposalExtension2 && fViewer != null)
 			((ICompletionProposalExtension2) proposal).selected(fViewer, smartToggle);
 
@@ -1621,19 +1628,20 @@ class CompletionProposalPopup implements IContentAssistListener {
 				fLastCompletionOffset= fFilterOffset;
 				fFilteredProposals= computeProposals(fInvocationOffset);
 
-				int count= (fFilteredProposals == null ? 0 : fFilteredProposals.size());
+				List<ICompletionProposal> proposals= fFilteredProposals;
+				int count= (proposals == null ? 0 : proposals.size());
 				if (count == 0 && hideWhenNoProposals(false))
 					return;
 
-				if (count == 1 && canAutoInsert(fFilteredProposals.get(0))) {
-					insertProposal(fFilteredProposals.get(0), (char) 0, 0, fInvocationOffset);
+				if (count == 1 && canAutoInsert(proposals.get(0))) {
+					insertProposal(proposals.get(0), (char) 0, 0, fInvocationOffset);
 					hide();
 				} else {
 					ensureDocumentListenerInstalled();
 					if (count > 0 && completeCommonPrefix())
 						hide();
 					else {
-						fComputedProposals= fFilteredProposals;
+						fComputedProposals= proposals;
 						createProposalSelector();
 						setProposals(fComputedProposals, false);
 						displayProposals();
