@@ -11,9 +11,12 @@
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *     Stephan Wahlbrink <sw@wahlbrink.eu> - Bug 512251 - Fix IllegalArgumentException in ContextInformationPopup
+ *     Stephan Wahlbrink <sw@wahlbrink.eu> - Bug 94106 - Fix hide/cleanup of content information popup stack
  *******************************************************************************/
 package org.eclipse.jface.text.contentassist;
 
+import static org.eclipse.jface.util.Util.isValid;
+
 import java.util.Stack;
 
 import org.eclipse.swt.SWT;
@@ -411,7 +414,7 @@ class ContextInformationPopup implements IContentAssistListener {
 	 * Creates the context information popup. This is the tool tip like overlay window.
 	 */
 	private void createContextInfoPopup() {
-		if (Helper.okToUse(fContextInfoPopup))
+		if (isValid(fContextInfoPopup))
 			return;
 
 		Control control= fContentAssistSubjectControlAdapter.getControl();
@@ -460,17 +463,20 @@ class ContextInformationPopup implements IContentAssistListener {
 
 	/**
 	 * Hides the context information popup.
+	 *
+	 * @param all <code>true</code> to hide popups at all,
+	 *     <code>false</code> to restore previous context frame if possible
 	 */
-	private void hideContextInfoPopup() {
+	private void hideContextInfoPopup(boolean all) {
 
-		if (Helper.okToUse(fContextInfoPopup)) {
+		if (isValid(fContextInfoPopup)) {
 
 			int size= fContextFrameStack.size();
 			while (size > 0) {
 				fLastContext= fContextFrameStack.pop();
 				-- size;
 
-				if (size > 0) {
+				if (size > 0 && !all) {
 					ContextFrame current= fContextFrameStack.peek();
 					if (canShowFrame(current)) {
 						internalShowContextFrame(current, false);
@@ -478,25 +484,20 @@ class ContextInformationPopup implements IContentAssistListener {
 					}
 					// continue - try next
 				}
-				else {
-					break;
-				}
 			}
-			{
-				fContentAssistant.removeContentAssistListener(this, ContentAssistant.CONTEXT_INFO_POPUP);
+			fContentAssistant.removeContentAssistListener(this, ContentAssistant.CONTEXT_INFO_POPUP);
 
-				if (fContentAssistSubjectControlAdapter.getControl() != null)
-					fContentAssistSubjectControlAdapter.removeSelectionListener(fTextWidgetSelectionListener);
-				fTextWidgetSelectionListener= null;
+			if (fContentAssistSubjectControlAdapter.getControl() != null)
+				fContentAssistSubjectControlAdapter.removeSelectionListener(fTextWidgetSelectionListener);
+			fTextWidgetSelectionListener= null;
 
-				fContextInfoPopup.setVisible(false);
-				fContextInfoPopup.dispose();
-				fContextInfoPopup= null;
+			fContextInfoPopup.setVisible(false);
+			fContextInfoPopup.dispose();
+			fContextInfoPopup= null;
 
-				if (fTextPresentation != null) {
-					fTextPresentation.clear();
-					fTextPresentation= null;
-				}
+			if (fTextPresentation != null) {
+				fTextPresentation.clear();
+				fTextPresentation= null;
 			}
 		}
 
@@ -509,7 +510,7 @@ class ContextInformationPopup implements IContentAssistListener {
 	 * at a given offset.
 	 */
 	private void createContextSelector() {
-		if (Helper.okToUse(fContextSelectorShell))
+		if (isValid(fContextSelectorShell))
 			return;
 
 		Control control= fContentAssistSubjectControlAdapter.getControl();
@@ -600,7 +601,7 @@ class ContextInformationPopup implements IContentAssistListener {
 	 */
 	int getMinimalHeight() {
 		int height= 0;
-		if (Helper.okToUse(fContextSelectorTable)) {
+		if (isValid(fContextSelectorTable)) {
 			int items= fContextSelectorTable.getItemHeight() * 10;
 			Rectangle trim= fContextSelectorTable.computeTrim(0, 0, SWT.DEFAULT, items);
 			height= trim.height;
@@ -639,7 +640,7 @@ class ContextInformationPopup implements IContentAssistListener {
 	 * @param selectionIndex the index of the proposal to select
 	 */
 	private void setContexts(IContextInformation[] contexts, int selectionIndex) {
-		if (Helper.okToUse(fContextSelectorTable)) {
+		if (isValid(fContextSelectorTable)) {
 
 			fContextSelectorInput= contexts;
 
@@ -673,7 +674,7 @@ class ContextInformationPopup implements IContentAssistListener {
 	 * Hides the context selector.
 	 */
 	private void hideContextSelector() {
-		if (Helper.okToUse(fContextSelectorShell)) {
+		if (isValid(fContextSelectorShell)) {
 			fContentAssistant.storeContextSelectorPopupSize();
 			fContentAssistant.removeContentAssistListener(this, ContentAssistant.CONTEXT_SELECTOR);
 
@@ -683,7 +684,7 @@ class ContextInformationPopup implements IContentAssistListener {
 			fContextSelectorShell= null;
 		}
 
-		if (!Helper.okToUse(fContextInfoPopup))
+		if (!isValid(fContextInfoPopup))
 			fContentAssistant.contextInformationClosed();
 	}
 
@@ -693,7 +694,7 @@ class ContextInformationPopup implements IContentAssistListener {
 	 * @return <code>true</code> if the context selector has the focus
 	 */
 	public boolean hasFocus() {
-		if (Helper.okToUse(fContextSelectorShell))
+		if (isValid(fContextSelectorShell))
 			return fContextSelectorShell.getDisplay().getActiveShell() == fContextSelectorShell;
 
 		return false;
@@ -704,7 +705,7 @@ class ContextInformationPopup implements IContentAssistListener {
 	 */
 	public void hide() {
 		hideContextSelector();
-		hideContextInfoPopup();
+		hideContextInfoPopup(true);
 	}
 
 	/**
@@ -714,14 +715,14 @@ class ContextInformationPopup implements IContentAssistListener {
 	 * @return <code>true</code> if the context selector is active
 	 */
 	public boolean isActive() {
-		return (Helper.okToUse(fContextInfoPopup) || Helper.okToUse(fContextSelectorShell));
+		return (isValid(fContextInfoPopup) || isValid(fContextSelectorShell));
 	}
 
 	@Override
 	public boolean verifyKey(VerifyEvent e) {
-		if (Helper.okToUse(fContextSelectorShell))
+		if (isValid(fContextSelectorShell))
 			return contextSelectorKeyPressed(e);
-		if (Helper.okToUse(fContextInfoPopup))
+		if (isValid(fContextInfoPopup))
 			return contextInfoPopupKeyPressed(e);
 		return true;
 	}
@@ -817,13 +818,13 @@ class ContextInformationPopup implements IContentAssistListener {
 					break;
 				default:
 					if (e.keyCode != SWT.CAPS_LOCK && e.keyCode != SWT.MOD1 && e.keyCode != SWT.MOD2 && e.keyCode != SWT.MOD3 && e.keyCode != SWT.MOD4)
-						hideContextInfoPopup();
+						hideContextInfoPopup(true);
 					break;
 			}
 
 		} else if (key == SWT.ESC) {
 			e.doit= false;
-			hideContextInfoPopup();
+			hideContextInfoPopup(false);
 		} else {
 			validateContextInformation();
 		}
@@ -832,9 +833,9 @@ class ContextInformationPopup implements IContentAssistListener {
 
 	@Override
 	public void processEvent(VerifyEvent event) {
-		if (Helper.okToUse(fContextSelectorShell))
+		if (isValid(fContextSelectorShell))
 			contextSelectorProcessEvent(event);
-		if (Helper.okToUse(fContextInfoPopup))
+		if (isValid(fContextInfoPopup))
 			contextInfoPopupProcessEvent(event);
 	}
 
@@ -859,7 +860,7 @@ class ContextInformationPopup implements IContentAssistListener {
 	 * @param e the verify event describing the key stroke
 	 */
 	private void contextInfoPopupProcessEvent(VerifyEvent e) {
-		if (e.start != e.end && (e.text == null || e.text.length() == 0))
+		if (e.start != e.end && (e.text == null || e.text.isEmpty()))
 			validateContextInformation();
 	}
 
@@ -873,7 +874,7 @@ class ContextInformationPopup implements IContentAssistListener {
 		 * Otherwise, we'd validate the context information based on the
 		 * pre-key-stroke state.
 		 */
-		if (!Helper.okToUse(fContextInfoPopup))
+		if (!isValid(fContextInfoPopup))
 			return;
 
 		fContextInfoPopup.getDisplay().asyncExec(new Runnable() {
@@ -887,10 +888,10 @@ class ContextInformationPopup implements IContentAssistListener {
 					int offset= fContentAssistSubjectControlAdapter.getSelectedRange().x;
 
 					// iterate all contexts on the stack
-					while (Helper.okToUse(fContextInfoPopup) && !fContextFrameStack.isEmpty()) {
+					while (isValid(fContextInfoPopup) && !fContextFrameStack.isEmpty()) {
 						ContextFrame top= fContextFrameStack.peek();
 						if (top.fValidator == null || !top.fValidator.isContextInformationValid(offset)) {
-							hideContextInfoPopup(); // loop variant: reduces the number of contexts on the stack
+							hideContextInfoPopup(false); // loop variant: reduces the number of contexts on the stack
 						} else if (top.fPresenter != null && top.fPresenter.updatePresentation(offset, fTextPresentation)) {
 							int widgetOffset= fContentAssistSubjectControlAdapter.getWidgetSelectionRange().x;
 							TextPresentation.applyTextPresentation(fTextPresentation, fContextInfoText);
