@@ -194,27 +194,36 @@ public class FileTreeContentProvider implements ITreeContentProvider, IFileSearc
 
 	@Override
 	public synchronized void elementsChanged(Object[] updatedElements) {
-		for (int i= 0; i < updatedElements.length; i++) {
-			if (!(updatedElements[i] instanceof LineElement)) {
-				// change events to elements are reported in file search
-				if (fResult.getMatchCount(updatedElements[i]) > 0)
-					insert(updatedElements[i], true);
-				else
-					remove(updatedElements[i], true);
-			} else {
-				// change events to line elements are reported in text search
-				LineElement lineElement= (LineElement) updatedElements[i];
-				int nMatches= lineElement.getNumberOfMatches(fResult);
-				if (nMatches > 0) {
-					if (hasChild(lineElement.getParent(), lineElement)) {
-						fTreeViewer.update(new Object[] { lineElement, lineElement.getParent() }, null);
+		boolean singleElement = updatedElements.length == 1;
+		try {
+			for (Object updatedElement : updatedElements) {
+				if (!(updatedElement instanceof LineElement)) {
+					// change events to elements are reported in file search
+					if (fResult.getMatchCount(updatedElement) > 0) {
+						insert(updatedElement, singleElement);
 					} else {
-						insert(lineElement, true);
+						remove(updatedElement, singleElement);
 					}
 				} else {
-					remove(lineElement, true);
+					// change events to line elements are reported in text
+					// search
+					LineElement lineElement = (LineElement) updatedElement;
+					int nMatches = lineElement.getNumberOfMatches(fResult);
+					if (nMatches > 0) {
+						if (singleElement && hasChild(lineElement.getParent(), lineElement)) {
+							fTreeViewer.update(new Object[] { lineElement, lineElement.getParent() }, null);
+						} else {
+							insert(lineElement, singleElement);
+						}
+					} else {
+						remove(lineElement, singleElement);
+					}
 				}
 			}
+		} finally {
+			if (updatedElements.length > 0 && !singleElement) {
+				fTreeViewer.refresh();
+			}
 		}
 	}
 
