@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -34,7 +34,8 @@ import org.junit.runners.Suite.SuiteClasses;
 		ZoomTest.class,
 		FileDocumentProviderTest.class,
 		TextFileDocumentProviderTest.class,
-		StatusEditorTest.class
+		StatusEditorTest.class,
+		LargeFileTest.class
 })
 public class EditorsTestSuite {
 	// see @SuiteClasses
