@@ -25,6 +25,7 @@ import java.nio.charset.Charset;
 import java.nio.charset.CharsetEncoder;
 import java.nio.charset.CodingErrorAction;
 import java.nio.charset.IllegalCharsetNameException;
+import java.nio.charset.StandardCharsets;
 import java.nio.charset.UnmappableCharacterException;
 import java.nio.charset.UnsupportedCharsetException;
 
@@ -88,29 +89,6 @@ import org.eclipse.ui.texteditor.ResourceMarkerAnnotationModel;
  */
 public class FileDocumentProvider extends StorageDocumentProvider {
 
-	/**
-	 * Qualified name for the encoding key.
-	 *
-	 * @since 2.1
-	 */
-	private static final QualifiedName ENCODING_KEY = new QualifiedName(EditorsUI.PLUGIN_ID, "encoding"); //$NON-NLS-1$
-	/**
-	 * Constant denoting UTF-8 encoding.
-	 * @since 3.0
-	 */
-	private static final String CHARSET_UTF_8= "UTF-8"; //$NON-NLS-1$
-	/**
-	 * Constant denoting UTF-16 encoding.
-	 * @since 3.4
-	 */
-	private static final String CHARSET_UTF_16= "UTF-16"; //$NON-NLS-1$
-	/**
-	 * Constant denoting UTF-16LE encoding.
-	 * @since 3.4
-	 */
-	private static final String CHARSET_UTF_16LE= "UTF-16LE"; //$NON-NLS-1$
-
-
 	/**
 	 * The runnable context for that provider.
 	 * @since 3.0
@@ -396,7 +374,7 @@ public class FileDocumentProvider extends StorageDocumentProvider {
 			try (InputStream contentStream= file.getContents(false)) {
 				FileInfo info= (FileInfo)getElementInfo(editorInput);
 				boolean removeBOM= false;
-				if (CHARSET_UTF_8.equals(encoding)) {
+				if (StandardCharsets.UTF_8.name().equals(encoding)) {
 					if (info != null)
 						removeBOM= info.fBOM != null;
 					else
@@ -549,8 +527,8 @@ public class FileDocumentProvider extends StorageDocumentProvider {
 			IFile file= input.getFile();
 			encoding= getCharsetForNewFile(file, document, info);
 
-			if (info != null && info.fBOM == IContentDescription.BOM_UTF_16LE && CHARSET_UTF_16.equals(encoding))
-				encoding= CHARSET_UTF_16LE;
+			if (info != null && info.fBOM == IContentDescription.BOM_UTF_16LE && StandardCharsets.UTF_16.name().equals(encoding))
+				encoding= StandardCharsets.UTF_16LE.name();
 
 			Charset charset;
 			try {
@@ -593,10 +571,10 @@ public class FileDocumentProvider extends StorageDocumentProvider {
 			 * This is a workaround for a corresponding bug in Java readers and writer,
 			 * see http://developer.java.sun.com/developer/bugParade/bugs/4508058.html
 			 */
-			if (info != null && info.fBOM == IContentDescription.BOM_UTF_8 && CHARSET_UTF_8.equals(encoding))
+			if (info != null && info.fBOM == IContentDescription.BOM_UTF_8 && StandardCharsets.UTF_8.name().equals(encoding))
 				stream= new SequenceInputStream(new ByteArrayInputStream(IContentDescription.BOM_UTF_8), stream);
 
-			if (info != null && info.fBOM == IContentDescription.BOM_UTF_16LE && CHARSET_UTF_16LE.equals(encoding))
+			if (info != null && info.fBOM == IContentDescription.BOM_UTF_16LE && StandardCharsets.UTF_16LE.name().equals(encoding))
 				stream= new SequenceInputStream(new ByteArrayInputStream(IContentDescription.BOM_UTF_16LE), stream);
 
 			if (file.exists()) {
@@ -688,10 +666,15 @@ public class FileDocumentProvider extends StorageDocumentProvider {
 
 			IFileEditorInput input= (IFileEditorInput) element;
 
-			try {
-				refreshFile(input.getFile());
-			} catch (CoreException x) {
-				handleCoreException(x, TextEditorMessages.FileDocumentProvider_createElementInfo);
+			// Note that file.isSynchronized does not require a scheduling rule and thus helps to identify a no-op attempt
+			// to refresh the file. The no-op will otherwise be blocked by a running build or cancel a running build
+			IFile file= input.getFile();
+			if (!file.isSynchronized(IResource.DEPTH_ZERO)) {
+				try {
+					refreshFile(file);
+				} catch (CoreException x) {
+					handleCoreException(x, TextEditorMessages.FileDocumentProvider_createElementInfo);
+				}
 			}
 
 			IDocument d= null;
@@ -1026,38 +1009,11 @@ public class FileDocumentProvider extends StorageDocumentProvider {
 	 */
 	@Override
 	protected String getPersistedEncoding(Object element) {
-		if (element instanceof IFileEditorInput) {
-			IFileEditorInput editorInput= (IFileEditorInput)element;
-			IFile file= editorInput.getFile();
-			if (file != null) {
-				String encoding= null;
-				try {
-					encoding= file.getPersistentProperty(ENCODING_KEY);
-				} catch (CoreException x) {
-					// we ignore exceptions here because we support the ENCODING_KEY property only for compatibility reasons
-				}
-				if (encoding != null) {
-					// if we found an old encoding property, we try to migrate it to the new core.resources encoding support
-					try {
-						file.setCharset(encoding, getProgressMonitor());
-						// if successful delete old property
-						file.setPersistentProperty(ENCODING_KEY, null);
-					} catch (CoreException ex) {
-						handleCoreException(ex, TextEditorMessages.FileDocumentProvider_getPersistedEncoding);
-					}
-				} else {
-					try {
-						encoding= file.getCharset();
-					} catch (CoreException e) {
-						return null;
-					}
-				}
-				return encoding;
-			}
-		}
 		return super.getPersistedEncoding(element);
 	}
 
+
+
 	/**
 	 * Persists the given encoding for the given element.
 	 *
@@ -1143,7 +1099,19 @@ public class FileDocumentProvider extends StorageDocumentProvider {
 	protected ISchedulingRule getValidateStateRule(Object element) {
 		if (element instanceof IFileEditorInput) {
 			IFileEditorInput input= (IFileEditorInput) element;
-			return fResourceRuleFactory.validateEditRule(new IResource[] { input.getFile() });
+			IFile file= input.getFile();
+			ISchedulingRule validateEditRule= fResourceRuleFactory.validateEditRule(new IResource[] { file });
+			if (validateEditRule == null) {
+				// Note that factory decides to provide a null rule for modifiable files (not read-only).
+				// Null rule means, that org.eclipse.core.internal.resources.WorkManager.checkIn(ISchedulingRule, IProgressMonitor)
+				// will run jobManager.beginRule(null, monitor); which will NOT show any progress dialog
+				// and will *immediately* lock UI thread via lock.acquire(); while the workspace is locked
+				// Providing here a file we enforce the progress dialog, where this operation can be cancelled by user,
+				// so that an occasional "Modify" or "Save" of the editor will NOT block UI forever.
+				return file;
+			} else {
+				return validateEditRule;
+			}
 		}
 		return null;
 	}
