@@ -109,7 +109,7 @@ class AnnotationsConfigurationBlock implements IPreferenceConfigurationBlock {
 	}
 
 
-	private final class ItemLabelProvider extends LabelProvider {
+	private static final class ItemLabelProvider extends LabelProvider {
 
 		@Override
 		public String getText(Object element) {
