@@ -179,12 +179,7 @@ public class AddMarkerAction extends TextEditorAction {
 		String proposal= (o instanceof String) ? (String) o : ""; //$NON-NLS-1$
 		String title= getString(fBundle, fPrefix + "dialog.title", fPrefix + "dialog.title"); //$NON-NLS-2$ //$NON-NLS-1$
 		String message= getString(fBundle, fPrefix + "dialog.message", fPrefix + "dialog.message"); //$NON-NLS-2$ //$NON-NLS-1$
-		IInputValidator inputValidator= new IInputValidator() {
-			@Override
-			public String isValid(String newText) {
-				return  (newText == null || newText.trim().length() == 0) ? " " : null;  //$NON-NLS-1$
-			}
-		};
+		IInputValidator inputValidator= newText -> (newText == null || newText.trim().isEmpty()) ? " " : null;
 		InputDialog dialog= new InputDialog(getTextEditor().getSite().getShell(), title, message, proposal, inputValidator);
 
 		String label= null;
@@ -195,7 +190,7 @@ public class AddMarkerAction extends TextEditorAction {
 			return false;
 
 		label= label.trim();
-		if (label.length() == 0)
+		if (label.isEmpty())
 			return false;
 
 		attributes.put("message", label); //$NON-NLS-1$
